@@ -15,8 +15,10 @@
 """
 import unittest
 
+from zope.interface.interface import InterfaceClass
 from zope.interface.tests import MissingSomeAttrs
 from zope.interface.tests import OptimizationTestMixin
+from zope.interface.tests import SubclassableMixin
 from zope.interface.tests.test_interface import \
     NameAndModuleComparisonTestsMixin
 
@@ -24,6 +26,25 @@ from zope.interface.tests.test_interface import \
 # pylint:disable=inherit-non-class,too-many-lines,protected-access
 # pylint:disable=blacklisted-name,attribute-defined-outside-init
 
+IBar = InterfaceClass('IBar')
+IFoo = InterfaceClass('IFoo')
+
+
+class Foo:
+    pass
+
+
+class FooImplementedNone:
+    __implemented__ = None
+
+
+class FooNoCall:
+    __implemented__ = None
+
+    def __call__(self):
+        raise NotImplementedError()
+
+
 class _Py3ClassAdvice:
 
     def _run_generated_code(
@@ -151,7 +172,6 @@ class DeclarationTests(EmptyDeclarationTests):
         self.assertEqual(list(decl.__bases__), [])
 
     def test_ctor_w_interface_in_bases(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         decl = self._makeOne(IFoo)
         self.assertEqual(list(decl.__bases__), [IFoo])
@@ -172,39 +192,33 @@ class DeclarationTests(EmptyDeclarationTests):
         self.assertNotIn(decl, decl)
 
     def test___contains__w_unrelated_iface(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         decl = self._makeOne()
         self.assertNotIn(IFoo, decl)
 
     def test___contains__w_base_interface(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         decl = self._makeOne(IFoo)
         self.assertIn(IFoo, decl)
 
     def test___iter___single_base(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         decl = self._makeOne(IFoo)
         self.assertEqual(list(decl), [IFoo])
 
     def test___iter___multiple_bases(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         IBar = InterfaceClass('IBar')
         decl = self._makeOne(IFoo, IBar)
         self.assertEqual(list(decl), [IFoo, IBar])
 
     def test___iter___inheritance(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         IBar = InterfaceClass('IBar', (IFoo,))
         decl = self._makeOne(IBar)
         self.assertEqual(list(decl), [IBar])  # IBar.interfaces() omits bases
 
     def test___iter___w_nested_sequence_overlap(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         IBar = InterfaceClass('IBar')
         decl = self._makeOne(IBar, (IFoo, IBar))
@@ -212,14 +226,12 @@ class DeclarationTests(EmptyDeclarationTests):
 
     def test_flattened_single_base(self):
         from zope.interface.interface import Interface
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         decl = self._makeOne(IFoo)
         self.assertEqual(list(decl.flattened()), [IFoo, Interface])
 
     def test_flattened_multiple_bases(self):
         from zope.interface.interface import Interface
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         IBar = InterfaceClass('IBar')
         decl = self._makeOne(IFoo, IBar)
@@ -227,7 +239,6 @@ class DeclarationTests(EmptyDeclarationTests):
 
     def test_flattened_inheritance(self):
         from zope.interface.interface import Interface
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         IBar = InterfaceClass('IBar', (IFoo,))
         decl = self._makeOne(IBar)
@@ -235,7 +246,6 @@ class DeclarationTests(EmptyDeclarationTests):
 
     def test_flattened_w_nested_sequence_overlap(self):
         from zope.interface.interface import Interface
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         IBar = InterfaceClass('IBar')
         # This is the same as calling ``Declaration(IBar, IFoo, IBar)``
@@ -247,7 +257,6 @@ class DeclarationTests(EmptyDeclarationTests):
         self.assertEqual(list(decl.flattened()), [IBar, IFoo, Interface])
 
     def test___sub___unrelated_interface(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         IBar = InterfaceClass('IBar')
         before = self._makeOne(IFoo)
@@ -256,14 +265,12 @@ class DeclarationTests(EmptyDeclarationTests):
         self.assertEqual(list(after), [IFoo])
 
     def test___sub___related_interface(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         before = self._makeOne(IFoo)
         after = before - IFoo
         self.assertEqual(list(after), [])
 
     def test___sub___related_interface_by_inheritance(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         IBar = InterfaceClass('IBar', (IFoo,))
         before = self._makeOne(IBar)
@@ -271,7 +278,6 @@ class DeclarationTests(EmptyDeclarationTests):
         self.assertEqual(list(after), [])
 
     def test___add___unrelated_interface(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         IBar = InterfaceClass('IBar')
         before = self._makeOne(IFoo)
@@ -280,7 +286,6 @@ class DeclarationTests(EmptyDeclarationTests):
         self.assertEqual(list(after), [IFoo, IBar])
 
     def test___add___related_interface(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         IBar = InterfaceClass('IBar')
         IBaz = InterfaceClass('IBaz')
@@ -297,7 +302,6 @@ class DeclarationTests(EmptyDeclarationTests):
         # the other way).
         from zope.interface import Interface
         from zope.interface import ro
-        from zope.interface.interface import InterfaceClass
         from zope.interface.tests.test_ro import C3Setting
 
         IBase = InterfaceClass('IBase')
@@ -444,7 +448,6 @@ class TestImplements(NameAndModuleComparisonTestsMixin,
 
     def test_sort(self):
         from zope.interface.declarations import implementedBy
-        from zope.interface.interface import InterfaceClass
 
         class A:
             pass
@@ -456,15 +459,16 @@ class TestImplements(NameAndModuleComparisonTestsMixin,
 
         self.assertEqual(implementedBy(A), implementedBy(A))
         self.assertEqual(hash(implementedBy(A)), hash(implementedBy(A)))
-        self.assertTrue(implementedBy(A) < None)
-        self.assertTrue(
-            None > implementedBy(A)
-        )  # pylint:disable=misplaced-comparison-constant
-        self.assertTrue(implementedBy(A) < implementedBy(B))
-        self.assertTrue(implementedBy(A) > IFoo)
-        self.assertTrue(implementedBy(A) <= implementedBy(B))
-        self.assertTrue(implementedBy(A) >= IFoo)
-        self.assertTrue(implementedBy(A) != IFoo)
+        self.assertLess(implementedBy(A), None)
+        self.assertGreater(
+            None,
+            implementedBy(A)
+        )
+        self.assertLess(implementedBy(A), implementedBy(B))
+        self.assertGreater(implementedBy(A), IFoo)
+        self.assertLessEqual(implementedBy(A), implementedBy(B))
+        self.assertGreaterEqual(implementedBy(A), IFoo)
+        self.assertNotEqual(implementedBy(A), IFoo)
 
     def test_proxy_equality(self):
         # https://github.com/zopefoundation/zope.interface/issues/55
@@ -495,19 +499,20 @@ class TestImplements(NameAndModuleComparisonTestsMixin,
 
         # The order of arguments to the operators matters,
         # test both
-        self.assertTrue(
-            implementedByA == implementedByA
-        )  # pylint:disable=comparison-with-itself
-        self.assertTrue(implementedByA != implementedByB)
-        self.assertTrue(implementedByB != implementedByA)
+        self.assertEqual(
+            implementedByA,
+            implementedByA
+        )
+        self.assertNotEqual(implementedByA, implementedByB)
+        self.assertNotEqual(implementedByB, implementedByA)
 
-        self.assertTrue(proxy == implementedByA)
-        self.assertTrue(implementedByA == proxy)
-        self.assertFalse(proxy != implementedByA)
-        self.assertFalse(implementedByA != proxy)
+        self.assertEqual(proxy, implementedByA)
+        self.assertEqual(implementedByA, proxy)
+        self.assertEqual(proxy, implementedByA)
+        self.assertEqual(implementedByA, proxy)
 
-        self.assertTrue(proxy != implementedByB)
-        self.assertTrue(implementedByB != proxy)
+        self.assertNotEqual(proxy, implementedByB)
+        self.assertNotEqual(implementedByB, proxy)
 
     def test_changed_deletes_super_cache(self):
         impl = self._makeOne()
@@ -580,7 +585,7 @@ class Test_implementedByFallback(unittest.TestCase):
         with _MonkeyDict(declarations,
                          'BuiltinImplementationSpecifications') as specs:
             specs[foo] = reg
-            self.assertTrue(self._callFUT(foo) is reg)
+            self.assertIs(self._callFUT(foo), reg)
 
     def test_dictless_w_existing_Implements(self):
         from zope.interface.declarations import Implements
@@ -591,10 +596,9 @@ class Test_implementedByFallback(unittest.TestCase):
 
         foo = Foo()
         foo.__implemented__ = impl
-        self.assertTrue(self._callFUT(foo) is impl)
+        self.assertIs(self._callFUT(foo), impl)
 
     def test_dictless_w_existing_not_Implements(self):
-        from zope.interface.interface import InterfaceClass
 
         class Foo:
             __slots__ = ('__implemented__',)
@@ -611,7 +615,7 @@ class Test_implementedByFallback(unittest.TestCase):
         class Foo:
             __implemented__ = impl
 
-        self.assertTrue(self._callFUT(Foo) is impl)
+        self.assertIs(self._callFUT(Foo), impl)
 
     def test_builtins_added_to_cache(self):
         from zope.interface import declarations
@@ -636,9 +640,9 @@ class Test_implementedByFallback(unittest.TestCase):
             specs[tuple] = t_spec
             specs[list] = l_spec
             specs[dict] = d_spec
-            self.assertTrue(self._callFUT(tuple) is t_spec)
-            self.assertTrue(self._callFUT(list) is l_spec)
-            self.assertTrue(self._callFUT(dict) is d_spec)
+            self.assertIs(self._callFUT(tuple), t_spec)
+            self.assertIs(self._callFUT(list), l_spec)
+            self.assertIs(self._callFUT(dict), d_spec)
 
     def test_oldstyle_class_no_assertions(self):
         # TODO: Figure out P3 story
@@ -666,14 +670,9 @@ class Test_implementedByFallback(unittest.TestCase):
 
     def test_w_None_no_bases_w_factory(self):
         from zope.interface.declarations import objectSpecificationDescriptor
+        from zope.interface.tests.test_declarations import FooNoCall
 
-        class Foo:
-            __implemented__ = None
-
-            def __call__(self):
-                raise NotImplementedError()
-
-        foo = Foo()
+        foo = FooNoCall()
         foo.__name__ = 'foo'
         spec = self._callFUT(foo)
         self.assertEqual(spec.__name__,
@@ -687,23 +686,22 @@ class Test_implementedByFallback(unittest.TestCase):
 
     def test_w_None_no_bases_w_class(self):
         from zope.interface.declarations import ClassProvides
+        from zope.interface.tests.test_declarations import FooImplementedNone
 
-        class Foo:
-            __implemented__ = None
-
-        spec = self._callFUT(Foo)
-        self.assertEqual(spec.__name__,
-                         'zope.interface.tests.test_declarations.Foo')
-        self.assertIs(spec.inherit, Foo)
-        self.assertIs(Foo.__implemented__, spec)
+        spec = self._callFUT(FooImplementedNone)
+        self.assertEqual(
+            spec.__name__,
+            'zope.interface.tests.test_declarations.FooImplementedNone')
+        self.assertIs(spec.inherit, FooImplementedNone)
+        self.assertIs(FooImplementedNone.__implemented__, spec)
         self.assertIsInstance(
-            Foo.__providedBy__, ClassProvides
+            FooImplementedNone.__providedBy__, ClassProvides
         )  # pylint:disable=no-member
         self.assertIsInstance(
-            Foo.__provides__, ClassProvides
+            FooImplementedNone.__provides__, ClassProvides
         )  # pylint:disable=no-member
         self.assertEqual(
-            Foo.__provides__, Foo.__providedBy__
+            FooImplementedNone.__provides__, FooImplementedNone.__providedBy__
         )  # pylint:disable=no-member
 
     def test_w_existing_Implements(self):
@@ -713,7 +711,7 @@ class Test_implementedByFallback(unittest.TestCase):
         class Foo:
             __implemented__ = impl
 
-        self.assertTrue(self._callFUT(Foo) is impl)
+        self.assertIs(self._callFUT(Foo), impl)
 
     def test_super_when_base_implements_interface(self):
         from zope.interface import Interface
@@ -910,7 +908,6 @@ class _ImplementsTestMixin:
                            spec_name=__name__ + '.Foo',
                            inherit="not given"):
         from zope.interface.declarations import ClassProvides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
 
         returned = self._callFUT(Foo, IFoo)
@@ -950,7 +947,6 @@ class Test_classImplementsOnly(_ImplementsTestMixin, unittest.TestCase):
 
     def test_w_existing_Implements(self):
         from zope.interface.declarations import Implements
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         IBar = InterfaceClass('IBar')
         impl = Implements(IFoo)
@@ -962,13 +958,12 @@ class Test_classImplementsOnly(_ImplementsTestMixin, unittest.TestCase):
         impl.inherit = Foo
         self._callFUT(Foo, IBar)
         # Same spec, now different values
-        self.assertTrue(Foo.__implemented__ is impl)
+        self.assertIs(Foo.__implemented__, impl)
         self.assertEqual(impl.inherit, None)
         self.assertEqual(impl.declared, (IBar,))
 
     def test_class(self):
         from zope.interface.declarations import Implements
-        from zope.interface.interface import InterfaceClass
         IBar = InterfaceClass('IBar')
         old_spec = Implements(IBar)
 
@@ -1050,7 +1045,6 @@ class Test_classImplements(_ImplementsTestMixin, unittest.TestCase):
 
     def test_w_existing_Implements(self):
         from zope.interface.declarations import Implements
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         IBar = InterfaceClass('IBar')
         impl = Implements(IFoo)
@@ -1069,7 +1063,6 @@ class Test_classImplements(_ImplementsTestMixin, unittest.TestCase):
 
     def test_w_existing_Implements_w_bases(self):
         from zope.interface.declarations import Implements
-        from zope.interface.interface import InterfaceClass
         IRoot = InterfaceClass('IRoot')
         ISecondRoot = InterfaceClass('ISecondRoot')
         IExtendsRoot = InterfaceClass('IExtendsRoot', (IRoot,))
@@ -1126,7 +1119,6 @@ class Test__implements_advice(unittest.TestCase):
     def test_no_existing_implements(self):
         from zope.interface.declarations import Implements
         from zope.interface.declarations import classImplements
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
 
         class Foo:
@@ -1156,22 +1148,17 @@ class Test_implementer(Test_classImplements):
         return decorator(cls)
 
     def test_nonclass_cannot_assign_attr(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         decorator = self._makeOne(IFoo)
         self.assertRaises(TypeError, decorator, object())
 
     def test_nonclass_can_assign_attr(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
-
-        class Foo:
-            pass
-
+        from zope.interface.tests.test_declarations import Foo
         foo = Foo()
         decorator = self._makeOne(IFoo)
         returned = decorator(foo)
-        self.assertTrue(returned is foo)
+        self.assertIs(returned, foo)
         spec = foo.__implemented__  # pylint:disable=no-member
         self.assertEqual(
             spec.__name__, 'zope.interface.tests.test_declarations.?'
@@ -1187,7 +1174,6 @@ class Test_implementer(Test_classImplements):
         # https://github.com/zopefoundation/zope.interface/issues/216
         import gc
 
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
 
         begin_count = len(gc.get_objects())
@@ -1224,7 +1210,6 @@ class Test_implementer_only(Test_classImplementsOnly):
         return decorator(cls)
 
     def test_function(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         decorator = self._makeOne(IFoo)
 
@@ -1234,7 +1219,6 @@ class Test_implementer_only(Test_classImplementsOnly):
         self.assertRaises(ValueError, decorator, _function)
 
     def test_method(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass('IFoo')
         decorator = self._makeOne(IFoo)
 
@@ -1255,7 +1239,6 @@ class ProvidesClassTests(unittest.TestCase):
         return self._getTargetClass()(*args, **kw)
 
     def test_simple_class_one_interface(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -1266,7 +1249,6 @@ class ProvidesClassTests(unittest.TestCase):
 
     def test___reduce__(self):
         from zope.interface.declarations import Provides  # the function
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -1278,7 +1260,6 @@ class ProvidesClassTests(unittest.TestCase):
         self.assertEqual(args, (Foo, IFoo))
 
     def test___get___class(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -1289,7 +1270,6 @@ class ProvidesClassTests(unittest.TestCase):
         self.assertIs(Foo.__provides__, spec)
 
     def test___get___instance(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -1353,7 +1333,6 @@ class TestProvidesClassRepr(unittest.TestCase):
         return self._getTargetClass()(*args, **kw)
 
     def test__repr__(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         assert IFoo.__name__ == 'IFoo'
         assert IFoo.__module__ == __name__
@@ -1394,11 +1373,9 @@ class TestProvidesClassRepr(unittest.TestCase):
 
         from zope.interface.declarations import alsoProvides
         from zope.interface.declarations import directlyProvides
-        from zope.interface.interface import InterfaceClass
         from zope.interface.tests import dummy
-
-        IFoo = InterfaceClass('IFoo')
-        IBar = InterfaceClass('IBar')
+        from zope.interface.tests.test_declarations import IBar
+        from zope.interface.tests.test_declarations import IFoo
 
         orig_provides = dummy.__provides__  # pylint:disable=no-member
         del dummy.__provides__  # pylint:disable=no-member
@@ -1424,7 +1401,7 @@ class TestProvidesClassRepr(unittest.TestCase):
 
         # If we make this module also provide IFoo and IBar, then the repr
         # lists both names.
-        my_module = sys.modules[__name__]
+        from zope.interface.tests import test_declarations as my_module
         assert not hasattr(my_module, '__provides__')
 
         directlyProvides(my_module, IFoo, IBar)
@@ -1439,7 +1416,6 @@ class TestProvidesClassRepr(unittest.TestCase):
 
     def test__repr__module_provides_cached_shared(self):
         from zope.interface.declarations import ModuleType
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         inst = self._makeOne(ModuleType, IFoo)
@@ -1451,7 +1427,6 @@ class TestProvidesClassRepr(unittest.TestCase):
         )
 
     def test__repr__duplicate_names(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo", __module__='mod1')
         IFoo2 = InterfaceClass("IFoo", __module__='mod2')
         IBaz = InterfaceClass("IBaz")
@@ -1510,7 +1485,6 @@ class TestProvidesClassRepr(unittest.TestCase):
     def test__repr__providedBy_from_class(self):
         from zope.interface.declarations import implementer
         from zope.interface.declarations import providedBy
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         @implementer(IFoo)
@@ -1527,7 +1501,6 @@ class TestProvidesClassRepr(unittest.TestCase):
         from zope.interface.declarations import alsoProvides
         from zope.interface.declarations import implementer
         from zope.interface.declarations import providedBy
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         IBar = InterfaceClass("IBar")
 
@@ -1553,7 +1526,6 @@ class Test_Provides(unittest.TestCase):
 
     def test_no_cached_spec(self):
         from zope.interface import declarations
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         cache = {}
 
@@ -1563,11 +1535,10 @@ class Test_Provides(unittest.TestCase):
         with _Monkey(declarations, InstanceDeclarations=cache):
             spec = self._callFUT(Foo, IFoo)
         self.assertEqual(list(spec), [IFoo])
-        self.assertTrue(cache[(Foo, IFoo)] is spec)
+        self.assertIs(cache[(Foo, IFoo)], spec)
 
     def test_w_cached_spec(self):
         from zope.interface import declarations
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         prior = object()
 
@@ -1577,7 +1548,7 @@ class Test_Provides(unittest.TestCase):
         cache = {(Foo, IFoo): prior}
         with _Monkey(declarations, InstanceDeclarations=cache):
             spec = self._callFUT(Foo, IFoo)
-        self.assertTrue(spec is prior)
+        self.assertIs(spec, prior)
 
 
 class Test_directlyProvides(unittest.TestCase):
@@ -1588,7 +1559,6 @@ class Test_directlyProvides(unittest.TestCase):
 
     def test_w_normal_object(self):
         from zope.interface.declarations import ProvidesClass
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -1605,7 +1575,6 @@ class Test_directlyProvides(unittest.TestCase):
 
     def test_w_class(self):
         from zope.interface.declarations import ClassProvides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -1621,7 +1590,6 @@ class Test_directlyProvides(unittest.TestCase):
 
     def test_w_classless_object(self):
         from zope.interface.declarations import ProvidesClass
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         the_dict = {}
 
@@ -1649,7 +1617,6 @@ class Test_alsoProvides(unittest.TestCase):
 
     def test_wo_existing_provides(self):
         from zope.interface.declarations import ProvidesClass
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -1667,7 +1634,6 @@ class Test_alsoProvides(unittest.TestCase):
     def test_w_existing_provides(self):
         from zope.interface.declarations import ProvidesClass
         from zope.interface.declarations import directlyProvides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         IBar = InterfaceClass("IBar")
 
@@ -1692,7 +1658,6 @@ class Test_noLongerProvides(unittest.TestCase):
         return noLongerProvides(*args, **kw)
 
     def test_wo_existing_provides(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -1706,7 +1671,6 @@ class Test_noLongerProvides(unittest.TestCase):
 
     def test_w_existing_provides_hit(self):
         from zope.interface.declarations import directlyProvides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -1721,7 +1685,6 @@ class Test_noLongerProvides(unittest.TestCase):
 
     def test_w_existing_provides_miss(self):
         from zope.interface.declarations import directlyProvides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         IBar = InterfaceClass("IBar")
 
@@ -1737,7 +1700,6 @@ class Test_noLongerProvides(unittest.TestCase):
 
     def test_w_iface_implemented_by_class(self):
         from zope.interface.declarations import implementer
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         @implementer(IFoo)
@@ -1767,17 +1729,15 @@ class ClassProvidesBaseFallbackTests(unittest.TestCase):
         return Derived(klass, implements)
 
     def test_w_same_class_via_class(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
             pass
 
         cpbp = Foo.__provides__ = self._makeOne(Foo, IFoo)
-        self.assertTrue(Foo.__provides__ is cpbp)
+        self.assertIs(Foo.__provides__, cpbp)
 
     def test_w_same_class_via_instance(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -1788,7 +1748,6 @@ class ClassProvidesBaseFallbackTests(unittest.TestCase):
         self.assertIs(foo.__provides__, IFoo)
 
     def test_w_different_class(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -1803,8 +1762,11 @@ class ClassProvidesBaseFallbackTests(unittest.TestCase):
         self.assertRaises(AttributeError, getattr, bar, '__provides__')
 
 
-class ClassProvidesBaseTests(OptimizationTestMixin,
-                             ClassProvidesBaseFallbackTests):
+class ClassProvidesBaseTests(
+    OptimizationTestMixin,
+    ClassProvidesBaseFallbackTests,
+    SubclassableMixin,
+):
     # Repeat tests for C optimizations
 
     def _getTargetClass(self):
@@ -1828,7 +1790,6 @@ class ClassProvidesTests(unittest.TestCase):
 
     def test_w_simple_metaclass(self):
         from zope.interface.declarations import implementer
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         IBar = InterfaceClass("IBar")
 
@@ -1837,12 +1798,11 @@ class ClassProvidesTests(unittest.TestCase):
             pass
 
         cp = Foo.__provides__ = self._makeOne(Foo, type(Foo), IBar)
-        self.assertTrue(Foo.__provides__ is cp)
+        self.assertIs(Foo.__provides__, cp)
         self.assertEqual(list(Foo().__provides__), [IFoo])
 
     def test___reduce__(self):
         from zope.interface.declarations import implementer
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         IBar = InterfaceClass("IBar")
 
@@ -1929,7 +1889,6 @@ class TestClassProvidesRepr(unittest.TestCase):
         )
 
     def test__repr__duplicate_names(self):
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo", __module__='mod1')
         IFoo2 = InterfaceClass("IFoo", __module__='mod2')
         IBaz = InterfaceClass("IBaz")
@@ -1943,7 +1902,6 @@ class TestClassProvidesRepr(unittest.TestCase):
     def test__repr__implementedBy(self):
         from zope.interface.declarations import implementedBy
         from zope.interface.declarations import implementer
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         @implementer(IFoo)
@@ -1996,7 +1954,6 @@ class Test_directlyProvidedBy(unittest.TestCase):
 
     def test_w_declarations_in_class_but_not_instance(self):
         from zope.interface.declarations import implementer
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         @implementer(IFoo)
@@ -2008,7 +1965,6 @@ class Test_directlyProvidedBy(unittest.TestCase):
 
     def test_w_declarations_in_instance_but_not_class(self):
         from zope.interface.declarations import directlyProvides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -2021,7 +1977,6 @@ class Test_directlyProvidedBy(unittest.TestCase):
     def test_w_declarations_in_instance_and_class(self):
         from zope.interface.declarations import directlyProvides
         from zope.interface.declarations import implementer
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         IBar = InterfaceClass("IBar")
 
@@ -2045,7 +2000,6 @@ class Test_provider(unittest.TestCase):
 
     def test_w_class(self):
         from zope.interface.declarations import ClassProvides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         @self._makeOne(IFoo)
@@ -2065,7 +2019,6 @@ class Test_moduleProvides(unittest.TestCase):
 
     def test_called_from_function(self):
         from zope.interface.declarations import moduleProvides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         globs = {'__name__': 'zope.interface.tests.foo',
                  'moduleProvides': moduleProvides, 'IFoo': IFoo}
@@ -2080,7 +2033,6 @@ class Test_moduleProvides(unittest.TestCase):
 
     def test_called_from_class(self):
         from zope.interface.declarations import moduleProvides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         globs = {'__name__': 'zope.interface.tests.foo',
                  'moduleProvides': moduleProvides, 'IFoo': IFoo}
@@ -2094,7 +2046,6 @@ class Test_moduleProvides(unittest.TestCase):
 
     def test_called_once_from_module_scope(self):
         from zope.interface.declarations import moduleProvides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         globs = {'__name__': 'zope.interface.tests.foo',
                  'moduleProvides': moduleProvides, 'IFoo': IFoo}
@@ -2107,7 +2058,6 @@ class Test_moduleProvides(unittest.TestCase):
 
     def test_called_twice_from_module_scope(self):
         from zope.interface.declarations import moduleProvides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         globs = {'__name__': 'zope.interface.tests.foo',
                  'moduleProvides': moduleProvides, 'IFoo': IFoo}
@@ -2154,7 +2104,6 @@ class Test_getObjectSpecificationFallback(unittest.TestCase):
 
     def test_existing_provides_is_spec(self):
         from zope.interface.declarations import directlyProvides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         def foo():
@@ -2175,7 +2124,6 @@ class Test_getObjectSpecificationFallback(unittest.TestCase):
 
     def test_existing_provides(self):
         from zope.interface.declarations import directlyProvides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -2188,7 +2136,6 @@ class Test_getObjectSpecificationFallback(unittest.TestCase):
 
     def test_wo_provides_on_class_w_implements(self):
         from zope.interface.declarations import implementer
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         @implementer(IFoo)
@@ -2275,7 +2222,6 @@ class Test_providedByFallback(unittest.TestCase):
 
     def test_w_providedBy_valid_spec(self):
         from zope.interface.declarations import Provides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -2298,7 +2244,6 @@ class Test_providedByFallback(unittest.TestCase):
 
     def test_w_providedBy_invalid_spec_class_w_implements(self):
         from zope.interface.declarations import implementer
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         @implementer(IFoo)
@@ -2319,7 +2264,7 @@ class Test_providedByFallback(unittest.TestCase):
         foo.__providedBy__ = object()
         expected = foo.__provides__ = object()
         spec = self._callFUT(foo)
-        self.assertTrue(spec is expected)
+        self.assertIs(spec, expected)
 
     def test_w_providedBy_invalid_spec_w_provides_diff_provides_on_class(self):
 
@@ -2331,11 +2276,10 @@ class Test_providedByFallback(unittest.TestCase):
         expected = foo.__provides__ = object()
         Foo.__provides__ = object()
         spec = self._callFUT(foo)
-        self.assertTrue(spec is expected)
+        self.assertIs(spec, expected)
 
     def test_w_providedBy_invalid_spec_w_provides_same_provides_on_class(self):
         from zope.interface.declarations import implementer
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         @implementer(IFoo)
@@ -2533,7 +2477,6 @@ class ObjectSpecificationDescriptorFallbackTests(unittest.TestCase):
 
     def test_accessed_via_class(self):
         from zope.interface.declarations import Provides
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
 
         class Foo:
@@ -2546,7 +2489,6 @@ class ObjectSpecificationDescriptorFallbackTests(unittest.TestCase):
     def test_accessed_via_inst_wo_provides(self):
         from zope.interface.declarations import Provides
         from zope.interface.declarations import implementer
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         IBar = InterfaceClass("IBar")
 
@@ -2563,7 +2505,6 @@ class ObjectSpecificationDescriptorFallbackTests(unittest.TestCase):
         from zope.interface.declarations import Provides
         from zope.interface.declarations import directlyProvides
         from zope.interface.declarations import implementer
-        from zope.interface.interface import InterfaceClass
         IFoo = InterfaceClass("IFoo")
         IBar = InterfaceClass("IBar")
         IBaz = InterfaceClass("IBaz")
@@ -2632,7 +2573,9 @@ class ObjectSpecificationDescriptorFallbackTests(unittest.TestCase):
 
 class ObjectSpecificationDescriptorTests(
         ObjectSpecificationDescriptorFallbackTests,
-        OptimizationTestMixin):
+        OptimizationTestMixin,
+        SubclassableMixin,
+):
     # Repeat tests for C optimizations
 
     def _getTargetClass(self):
